[−][src]Crate fastly
User API for Compute@Edge.
Note: this is currently a beta preview of an upcoming fastly crate version. In particular,
the documentation is not yet complete, and may contain some inaccuracies where content is left
over from the previous versions.
Re-exports
pub use crate::error::SendError; |
pub use crate::request::Request; |
pub use crate::response::Response; |
pub use http; |
pub use mime; |
Modules
| convert | |
| dictionary | Edge dictionary lookup functions. Dictionaries for Compute@Edge. |
| error | Error-handling. Error-handling utilities. |
| geo | Geographic data for IP addresses. Geographic data for IP addresses. |
| handle | |
| limits | |
| log | Logging utilities. Interface to Fastly's Real-Time Log Streaming endpoints. |
| request | HTTP requests. |
| response | HTTP responses. |
Macros
| panic_with_status |
Structs
| Backend | A named backend. |
| Body | An HTTP body that can be read from, written to, or appended to another body. |
| Error | The |
| Method | The Request Method (VERB) |
| Mime | A parsed mime or media type. |
| PendingRequest | A handle to a pending asynchronous request returned by
|
| StreamingBody | A streaming HTTP body that can be written to, or appended to from another body. |
| Url | A parsed URL record. |
Enums
| BackendError |
|
Traits
| ToHeaderName | |
| ToHeaderValue |
Functions
| init | Tell the runtime what ABI version this program is using. |
| select | Given a collection of |
| uap_parse | Parse a user agent string. |
Attribute Macros
| main | Main function attribute for a Compute@Edge program. |