#[non_exhaustive]pub enum CacheError {
LimitExceeded,
InvalidOperation,
Unsupported,
Timeout,
Other(FastlyStatus),
}Expand description
Errors arising from cache operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
LimitExceeded
Operation failed due to a limit.
InvalidOperation
Operation was not valid to be performed given the state of the cached item.
Unsupported
Cache operation is not supported.
Timeout
The cache operation did not complete within the timeout supplied by the caller.
This is returned by timeout-bounded operations such as
PendingTransaction::wait_for() when the timeout elapses before the operation completes.
Other(FastlyStatus)
An unknown error occurred.