pub struct CacheEntry {
pub value: Body,
pub ttl: Duration,
}Expand description
The return type of the closure provided to get_or_set_with().
Fields
value: BodyThe value to cache.
Argument type conversion
See the From impls for Body to see which types can be used as a body.
ttl: DurationThe time-to-live for the cache entry.