Module compute_runtime

Module compute_runtime 

Functions for interacting with the runtime of the Compute service.

Functions

cache_generation
The current cache identifier for this Fastly service.
customer_id
The customer ID of the Fastly customer account to which the currently executing service belongs.
elapsed_vcpu_ms
Get the amount of vCPU time that has passed since this instance was started, in milliseconds.
heap_memory_snapshot_mib
Get the current dynamic memory usage of this sandbox, rounded up to the nearest mebibyte (2^20 bytes).
hostname
The hostname of the Fastly cache server which is executing the current instance, for example, cache-jfk1034.
is_staging
Whether the request is running in the service’s staging environment.
pop
The three-character identifying code of the Fastly POP in which the current instance is running.
region
A code representing the general region of the world in which the Fastly POP processing the current Compute instance resides.
sandbox_id
A UUID generated by Fastly for each sandbox.
service_id
The identifier for the Fastly service that is processing the current request.
service_version
The version number for the Fastly service that is processing the current request.