pub fn service_version() -> u64Expand description
The version number for the Fastly service that is processing the current request.
Equivalent to the “FASTLY_SERVICE_VERSION” environment variable and to req.vcl.version
in VCL.
pub fn service_version() -> u64The version number for the Fastly service that is processing the current request.
Equivalent to the “FASTLY_SERVICE_VERSION” environment variable and to req.vcl.version
in VCL.