#[non_exhaustive]pub enum HandleError {
ClosedHandle(HandleKind),
InvalidHandle,
}Expand description
HandleError is for errors that might arise when using the low level handle
interface. For example trying to use a handle for an operation that has
already been closed out.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ClosedHandle(HandleKind)
When using close on a handle, this error will be thrown if the resource for the handle has been removed from the session already
InvalidHandle
A handle did not exist or was the wrong type