Module experimental

Module experimental 

Experimental Compute features.

These features are not yet stable and may change in backwards-incompatible ways without major-version bumps.

Re-exports

pub use crate::backend::BackendBuilder;
pub use crate::backend::BackendCreationError;
pub use crate::Response;

Modules

reusable_sessionsDeprecated
Support for reusable sandboxes. See deprecation notice.
shieldingDeprecated
Experimental shielding support. See deprecation notice.

Enums

BackendHealth
BodyHandleError
Errors that can arise from reading trailer information.

Traits

BackendExt
An extension trait for experimental Backend methods.
BodyExt
Extensions to the crate::http::body::Body type to support trailers.
BodyHandleExt
Extensions to the crate::handle::BodyHandle type to support trailers.
GrpcBackend
An extension trait to support gRPC backend definition.
RequestCacheKey
An extension trait for Requests that adds methods for controlling cache keys.
RequestHandleCacheKey
An extension trait for RequestHandles that adds methods for controlling cache keys.
RequestHandleUpgradeWebsocket
An extension trait for RequestHandles that adds methods for upgrading websockets.
RequestUpgradeWebsocket
An extension trait for Requests that adds a method for upgrading websockets.
StreamingBodyExt
Extensions to the crate::http::body::StreamingBody type to support trailers.

Functions

uap_parseDeprecated
Parse a user agent string.