pub struct Dictionary { /* private fields */ }👎Deprecated since 0.8.6: renamed to
ConfigStoreExpand description
A Compute Dictionary.
Implementations
Sourceimpl Dictionary
impl Dictionary
Sourcepub fn try_open(name: &str) -> Result<Self, OpenError>
👎Deprecated since 0.8.6: use method on ConfigStore instead
pub fn try_open(name: &str) -> Result<Self, OpenError>
ConfigStore insteadSourcepub fn get(&self, key: &str) -> Option<String>
👎Deprecated since 0.8.6: use method on ConfigStore instead
pub fn get(&self, key: &str) -> Option<String>
ConfigStore insteadLookup a value in this dictionary.
If successful, this function returns Some(_) if an entry was found, or None if no entry
with the given key was found.
Examples
ⓘ
assert_eq!(
dictionary.get("bread"),
Some(String::from("a usually baked and leavened food")),
);
assert_eq!(
dictionary.get("freedom"),
Some(String::from("the absence of necessity, coercion, or constraint")),
);
// Otherwise, `get` will return nothing.
assert!(dictionary.get("zzzzz").is_none());Panics
This may panic for any of the reasons that Dictionary::try_get would return an error.
Sourcepub fn try_get(&self, key: &str) -> Result<Option<String>, LookupError>
👎Deprecated since 0.8.6: use method on ConfigStore instead
pub fn try_get(&self, key: &str) -> Result<Option<String>, LookupError>
ConfigStore insteadTry to lookup a value in this dictionary.
If successful, this function returns Ok(Some(_)) if an entry was found, or Ok(None) if
no entry with the given key was found. This function returns Err(_) if the lookup failed.
Examples
ⓘ
assert_eq!(
dictionary.try_get("bread")?,
Some(String::from("a usually baked and leavened food")),
);
assert_eq!(
dictionary.try_get("freedom")?,
Some(String::from("the absence of necessity, coercion, or constraint")),
);
// Otherwise, `try_get` will return nothing.
assert!(dictionary.try_get("zzzzz")?.is_none());
Ok(()) }Sourcepub fn contains(&self, key: &str) -> bool
👎Deprecated since 0.8.6: use method on ConfigStore instead
pub fn contains(&self, key: &str) -> bool
ConfigStore insteadReturn true if the dictionary contains an entry with the given key.
Examples
ⓘ
assert!(dictionary.contains("key"));Panics
This may panic for any of the reasons that Dictionary::try_get would return an error.