pub struct SecretStore { /* private fields */ }Expand description
A Compute Secret Store.
A secret store name has a maximum length of 255 bytes and must contain only letters, numbers, dashes (-), underscores (_), and periods (.).
Implementations
Sourceimpl SecretStore
impl SecretStore