Functions for interacting with the runtime of the Compute service.
Functions
- cache_
generation - The current cache identifier for this Fastly service.
- customer_
id - The customer ID of the Fastly customer account to which the currently executing service belongs.
- elapsed_
vcpu_ ms - Get the amount of vCPU time that has passed since this instance was started, in milliseconds.
- heap_
memory_ snapshot_ mib - Get the current dynamic memory usage of this sandbox, rounded up to the nearest mebibyte (2^20 bytes).
- hostname
- The hostname of the Fastly cache server which is executing the current instance, for
example,
cache-jfk1034. - is_
staging - Whether the request is running in the service’s staging environment.
- pop
- The three-character identifying code of the Fastly POP in which the current instance is running.
- region
- A code representing the general region of the world in which the Fastly POP processing the current Compute instance resides.
- sandbox_
id - A UUID generated by Fastly for each sandbox.
- service_
id - The identifier for the Fastly service that is processing the current request.
- service_
version - The version number for the Fastly service that is processing the current request.